#
# spec file for package oras
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           oras
Version:        1.2.0
Release:        1.2
Summary:        OCI registry client - manage content like artifacts, images, packages
License:        Apache-2.0
URL:            https://github.com/oras-project/oras
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.22

%description
ORAS is the de facto tool for working with OCI Artifacts. It treats media types
as a critical piece of the puzzle. Container images are never assumed to be the
artifact in question. ORAS provides CLI and client libraries to distribute
artifacts across OCI-compliant registries.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X oras.land/oras/internal/version.BuildMetadata= \
   -X oras.land/oras/internal/version.gitCommit=v${COMMIT_HASH} \
   -X oras.land/oras/internal/version.GitTreeState=clean" \
   -o bin/%{name} oras.land/oras/cmd/oras

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%defattr(-,root,root)
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{name}

%changelog
* Thu Jul 11 2024 opensuse_buildservice@ojkastl.de
- add completion subpackages
- Update to version 1.2.0:
  * bump: tag and release ORAS CLI v1.2.0
  * fix: remove call to deprecated print (#1392)
  * doc: verify local files (#1386)
  * chore: Remove deprecated PrintStatus method (#1389)
  * build(deps): bump github.com/onsi/ginkgo/v2 from 2.18.0 to
    2.19.0 in /test/e2e (#1390)
  * build(deps): bump github.com/onsi/ginkgo/v2 from 2.17.3 to
    2.18.0 in /test/e2e (#1388)
  * refactor: Get rid of deprecated PrintStatus method (#1378)
  * build(deps): bump actions/checkout from 3 to 4 (#1385)
  * fix: oras cp documentation (#1384)
  * fix: remove non-classic snap plugins (#1383)
* Mon Dec  4 2023 Dirk Müller <dmueller@suse.com>
- Initial package (1.1.0)
